==> klayout-0.21.19.tar.gz: klayout-0.21.19/testdata/ruby/laySession.rb <==

use_minitest = (RUBY_VERSION =~ /^1\.9/)

if use_minitest
  require "minitest/unit"
  test_base = MiniTest::Unit::TestCase
else
  require "test/unit"
  test_base = Test::Unit::TestCase
end

class TestImpl < test_base

  def lnode_str( space, l )
    return space + l.current.source( true ) + "\n";
  end

  def lnodes_str( space, l )
    res = ""
    while ! l.at_end?  
      res += lnode_str( space, l )
      if (l.current.has_children?) 
        l.down_first_child
        res += lnodes_str( "  #{space}", l )
        l.up
      end
      l.next_sibling( 1 )
    end
    return res
  end

  def test_1

    app = RBA::Application.instance
    mw = app.main_window

    mw.reader_options.set_layer_map( RBA::LayerMap::new, true )
    mw.reader_options.text_enabled = true
    mw.reader_options.properties_enabled = true
    mw.load_layout( "../../testdata/gds/t11.gds", 1 )  # @@@

    mw.reader_options.create_other_layers = false
    mw.reader_options.layer_map.map( RBA::LayerInfo::new(1, 0), 1 )
    mw.reader_options.layer_map.map( "2/0", 0 )
    mw.reader_options.layer_map.map( "3/0", 2 )
    mw.reader_options.layer_map.map( "3/1", 10 )
    mw.reader_options.text_enabled = false
    mw.reader_options.properties_enabled = true
    mw.load_layout( "../../testdata/gds/t10.gds", 1 )  # @@@

    mw.select_view(0)

    cv = mw.current_view

    cv.clear_layers

    pos = cv.end_layers

    l1 = cv.insert_layer( pos, RBA::LayerPropertiesNode::new )

    new_p = RBA::LayerPropertiesNode::new
    new_p.source = "1/0@1"
    l11 = cv.insert_layer( pos.last_child, new_p )

    mw.save_session("tmp.lys")

    mw.close_all

    assert_equal(0, mw.views);

    mw.restore_session("tmp.lys")

    assert_equal(2, mw.views);

    cv = mw.current_view
    assert_equal( cv.title, "t11.gds" )
    assert_equal( lnodes_str( "", cv.begin_layers ), "*/*@*\n  1/0@1\n" )

    mw.select_view(1)

    cv = mw.current_view
    assert_equal( cv.title, "t10.gds" )
    assert_equal( lnodes_str( "", cv.begin_layers ), "1/0@1\n2/0@1\n3/0@1\n" )

  end

end

# In the test environment, we cannot make sure that we destroy the ruby interpreter before the RBA
# environment is shut down. Therefore we must release all RBA objects by explicitly calling the GC
# and start the test suite manually.

if !use_minitest
  # Ruby 1.8.7 with test/unit:
  require 'test/unit/ui/console/testrunner'
  res = Test::Unit::UI::Console::TestRunner.run(TestImpl) 
  res = res.error_count + res.failure_count
else
  # Ruby 1.9.1 with minitest/unit:
  # Make sure that _test_01 is run as the first one - to have a zero instance count of "A"
  res = MiniTest::Unit.new.run(["-n", "/^test_FIRST$/"])
  res ||= MiniTest::Unit.new.run(["-n", "/^test_\\d/"])
end

GC.start

exit 1 unless !res || res == 0

==> klayout-0.23.10.tar.gz: klayout-0.23.10/testdata/ruby/laySession.rb <==

use_minitest = (RUBY_VERSION >= "1.9.1")

if use_minitest
  require "minitest/unit"
  test_base = MiniTest::Unit::TestCase
else
  require "test/unit"
  test_base = Test::Unit::TestCase
end

class TestImpl < test_base

  def lnode_str( space, l )
    return space + l.current.source( true ) + "\n";
  end

  def lnodes_str( space, l )
    res = ""
    while ! l.at_end?  
      res += lnode_str( space, l )
      if (l.current.has_children?) 
        l.down_first_child
        res += lnodes_str( "  #{space}", l )
        l.up
      end
      l.next_sibling( 1 )
    end
    return res
  end

  def test_1

    app = RBA::Application.instance
    mw = app.main_window

    mw.reader_options.set_layer_map( RBA::LayerMap::new, true )
    mw.reader_options.text_enabled = true
    mw.reader_options.properties_enabled = true
    mw.load_layout( "../../testdata/gds/t11.gds", 1 )  # @@@

    mw.reader_options.create_other_layers = false
    mw.reader_options.layer_map.map( RBA::LayerInfo::new(1, 0), 1 )
    mw.reader_options.layer_map.map( "2/0", 0 )
    mw.reader_options.layer_map.map( "3/0", 2 )
    mw.reader_options.layer_map.map( "3/1", 10 )
    mw.reader_options.text_enabled = false
    mw.reader_options.properties_enabled = true
    mw.load_layout( "../../testdata/gds/t10.gds", 1 )  # @@@

    mw.select_view(0)

    cv = mw.current_view

    cv.clear_layers

    pos = cv.end_layers

    l1 = cv.insert_layer( pos, RBA::LayerPropertiesNode::new )

    new_p = RBA::LayerPropertiesNode::new
    new_p.source = "1/0@1"
    l11 = cv.insert_layer( pos.last_child, new_p )

    mw.save_session("tmp.lys")

    mw.close_all

    assert_equal(0, mw.views);

    mw.restore_session("tmp.lys")

    assert_equal(2, mw.views);

    cv = mw.current_view
    assert_equal( cv.title, "t11.gds" )
    assert_equal( lnodes_str( "", cv.begin_layers ), "*/*@*\n  1/0@1\n" )

    mw.select_view(1)

    cv = mw.current_view
    assert_equal( cv.title, "t10.gds" )
    assert_equal( lnodes_str( "", cv.begin_layers ), "1/0@1\n2/0@1\n3/0@1\n3/1@1\n" )

  end

end

# In the test environment, we cannot make sure that we destroy the ruby interpreter before the RBA
# environment is shut down. Therefore we must release all RBA objects by explicitly calling the GC
# and start the test suite manually.

if !use_minitest
  # Ruby 1.8.7 with test/unit:
  require 'test/unit/ui/console/testrunner'
  res = Test::Unit::UI::Console::TestRunner.run(TestImpl) 
  res = res.error_count + res.failure_count
else
  # Ruby 1.9.1 with minitest/unit:
  # Make sure that _test_01 is run as the first one - to have a zero instance count of "A"
  res = MiniTest::Unit.new.run(["-n", "/^test_FIRST$/"])
  res ||= MiniTest::Unit.new.run(["-n", "/^test_\\d/"])
end

GC.start

exit 1 unless !res || res == 0
